==> remote_ui-0.0.3.tar.gz: example/lib/main_test.dart <==
import 'package:flutter/material.dart';
import 'package:remote_ui/remote_ui.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  void _incrementCounter() {
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: <Widget>[
            Expanded(
              child: RemoteManagerWidget(
                onChanges: (key, value, {associatedData}) => debugPrint('$key change to $value'),
                child: RemoteWidget(
                  data: {},
                  definition: {
                    "type": "column",
                    "widgetWidth": 1,
                    "widgetHeight": 2,
                    "children": [
                      {
                        "type": "row",
                        "flex": 2,
                        "children": [
                          {
                            "type": "image_button",
                            "id": "power",
                            "value": "on",
                            "values": {"on": "/images/widgets/outlet_on.png", "off": "/images/widgets/outlet_off.png"}
                          },
                          {
                            "type": "column",
                            "children": [
                              {"type": "text", "id": "power", "value": "on"}
                            ]
                          }
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "crossAxisAlignment": 3,
                        "children": [
                          {"type": "raised_button", "id": "preset", "flex": 3, "text": "1", "value": 1},
                          {"type": "raised_button", "id": "preset", "flex": 3, "text": "2", "value": 2},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "3", "value": 3}
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "crossAxisAlignment": 3,
                        "children": [
                          {"type": "raised_button", "name": "preset", "text": "4", "flex": 3, "value": 4},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "5", "value": 5},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "6", "value": 6}
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "children": [
                          {"type": "image_button", "id": "previous", "flex": 1, "width": 30, "height": 30, "value": "/images/icons/media-step-backward.svg"},
                          {
                            "type": "image_button",
                            "flex": 1,
                            "id": "playpause",
                            "width": 30,
                            "height": 30,
                            "value": "\$state\$",
                            "values": {"pause": "/images/icons/media-pause.svg", "play": "/images/icons/media-play.svg"}
                          },
                          {"type": "image_button", "id": "stop", "width": 30, "height": 30, "flex": 1, "value": "/images/icons/media-stop.svg"},
                          {"type": "image_button", "width": 30, "height": 30, "id": "next", "flex": 1, "value": "/images/icons/media-step-forward.svg"}
                        ]
                      },
                      {"type": "slider", "id": "volume", "value": "\$volume\$", "min": 0, "max": 100, "divisions": 100, "flex": 1}
                    ]
                  },
                ),
              ),
            ),
            Text(
              'You have pushed the button this many times:',
              textAlign: TextAlign.center,
            ),
            Text(
              '$_counter',
              textAlign: TextAlign.center,
              style: Theme.of(context).textTheme.display1,
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}

==> remote_ui-0.0.10.tar.gz: example/lib/main_test.dart <==
import 'package:flutter/material.dart';
import 'package:remote_ui/remote_ui.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  void _incrementCounter() {
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: <Widget>[
            Expanded(
              child: RemoteManagerWidget(
                onChanges: (key, value, {associatedData}) => debugPrint('$key change to $value'),
                child: RemoteWidget(
                  data: {},
                  definition: {
                    "type": "column",
                    "widgetWidth": 1,
                    "widgetHeight": 2,
                    "children": [
                      {
                        "type": "row",
                        "flex": 2,
                        "children": [
                          {
                            "type": "image_button",
                            "id": "power",
                            "value": "on",
                            "values": {"on": "/images/widgets/outlet_on.png", "off": "/images/widgets/outlet_off.png"}
                          },
                          {
                            "type": "column",
                            "children": [
                              {"type": "text", "id": "power", "value": "on"}
                            ]
                          }
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "crossAxisAlignment": 3,
                        "children": [
                          {"type": "raised_button", "id": "preset", "flex": 3, "text": "1", "value": 1},
                          {"type": "raised_button", "id": "preset", "flex": 3, "text": "2", "value": 2},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "3", "value": 3}
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "crossAxisAlignment": 3,
                        "children": [
                          {"type": "raised_button", "name": "preset", "text": "4", "flex": 3, "value": 4},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "5", "value": 5},
                          {"type": "raised_button", "name": "preset", "flex": 3, "text": "6", "value": 6}
                        ]
                      },
                      {
                        "type": "row",
                        "flex": 2,
                        "children": [
                          {"type": "image_button", "id": "previous", "flex": 1, "width": 30, "height": 30, "value": "/images/icons/media-step-backward.svg"},
                          {
                            "type": "image_button",
                            "flex": 1,
                            "id": "playpause",
                            "width": 30,
                            "height": 30,
                            "value": "\$state\$",
                            "values": {"pause": "/images/icons/media-pause.svg", "play": "/images/icons/media-play.svg"}
                          },
                          {"type": "image_button", "id": "stop", "width": 30, "height": 30, "flex": 1, "value": "/images/icons/media-stop.svg"},
                          {"type": "image_button", "width": 30, "height": 30, "id": "next", "flex": 1, "value": "/images/icons/media-step-forward.svg"}
                        ]
                      },
                      {"type": "slider", "id": "volume", "value": "\$volume\$", "min": 0, "max": 100, "divisions": 100, "flex": 1}
                    ]
                  },
                ),
              ),
            ),
            Text(
              'You have pushed the button this many times:',
              textAlign: TextAlign.center,
            ),
            Text(
              '$_counter',
              textAlign: TextAlign.center,
              style: Theme.of(context).textTheme.headline4,
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        child: Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}
